==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/interkurier.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	interkurier.lang.inc.php 2018-02-16
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_INTERKURIER_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll, z. B.: AT,DE.',
	'MODULE_SHIPPING_INTERKURIER_ALLOWED_TITLE' => 'Einzelne Versandzonen',
	'MODULE_SHIPPING_INTERKURIER_COST_1_DESC' => 'Versandkosten Zone 1',
	'MODULE_SHIPPING_INTERKURIER_COST_1_TITLE' => 'Tarife Zone 1',
	'MODULE_SHIPPING_INTERKURIER_COST_2_DESC' => 'Versandkosten Zone 2',
	'MODULE_SHIPPING_INTERKURIER_COST_2_TITLE' => 'Tarife Zone 2',
	'MODULE_SHIPPING_INTERKURIER_COST_3_DESC' => 'Versandkosten Zone 3',
	'MODULE_SHIPPING_INTERKURIER_COST_3_TITLE' => 'Tarife Zone 3',
	'MODULE_SHIPPING_INTERKURIER_COST_4_DESC' => 'Versandkosten Zone 4',
	'MODULE_SHIPPING_INTERKURIER_COST_4_TITLE' => 'Tarife Zone 4',
	'MODULE_SHIPPING_INTERKURIER_COST_5_DESC' => 'Versandkosten Zone 5',
	'MODULE_SHIPPING_INTERKURIER_COST_5_TITLE' => 'Tarife Zone 5',
	'MODULE_SHIPPING_INTERKURIER_COST_6_DESC' => 'Versandkosten Zone 6',
	'MODULE_SHIPPING_INTERKURIER_COST_6_TITLE' => 'Tarife Zone 6',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_1_DESC' => 'Komma getrennte ISO-Kürzel für Zone 1:',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_1_TITLE' => 'Länder für Zone 1',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_2_DESC' => 'Komma getrennte ISO-Kürzel für Zone 2:',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_2_TITLE' => 'Länder für Zone 2',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_3_DESC' => 'Komma getrennte ISO-Kürzel für Zone 3:',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_3_TITLE' => 'Länder für Zone 3',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_4_DESC' => 'Komma getrennte ISO-Kürzel für Zone 4:',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_4_TITLE' => 'Länder für Zone 4',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_5_DESC' => 'Komma getrennte ISO-Kürzel für Zone 5:',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_5_TITLE' => 'Länder für Zone 5',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_6_DESC' => 'Komma getrennte ISO-Kürzel für Zone 6:',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_6_TITLE' => 'Länder für Zone 6',
	'MODULE_SHIPPING_INTERKURIER_FETCH_CITY_DESC' => 'Geben Sie Ihren Ort an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_CITY_TITLE' => 'Ort',
	'MODULE_SHIPPING_INTERKURIER_FETCH_COUNTRY_DESC' => 'Geben Sie Ihr Land an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_COUNTRY_TITLE' => 'Land',
	'MODULE_SHIPPING_INTERKURIER_FETCH_EMAIL_DESC' => 'Geben Sie Ihren Email an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_EMAIL_TITLE' => 'Email',
	'MODULE_SHIPPING_INTERKURIER_FETCH_FIRM_DESC' => 'Geben Sie Ihren Firmennamen an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_FIRM_TITLE' => 'Paketabholadresse: <br>Firmenname',
	'MODULE_SHIPPING_INTERKURIER_FETCH_NAME_DESC' => 'Geben Sie Ihren Vor- und Zunamen an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_NAME_TITLE' => 'Vor-Zuname',
	'MODULE_SHIPPING_INTERKURIER_FETCH_PHONE_DESC' => 'Geben Sie Ihre Telefonnummer an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_PHONE_TITLE' => 'Telefonnummer',
	'MODULE_SHIPPING_INTERKURIER_FETCH_POSTCODE_DESC' => 'Geben Sie Ihre PLZ an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_POSTCODE_TITLE' => 'PLZ',
	'MODULE_SHIPPING_INTERKURIER_FETCH_STREET_DESC' => 'Geben Sie Ihre Straße an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_STREET_TITLE' => 'Straße / Hausnummer',
	'MODULE_SHIPPING_INTERKURIER_HANDLING_DESC' => 'Bearbeitungszuschlag für diese Versandart in Euro',
	'MODULE_SHIPPING_INTERKURIER_HANDLING_TITLE' => 'Zuschlag',
	'MODULE_SHIPPING_INTERKURIER_INVALID_ZONE' => 'Diese Option steht für ihre Lieferadresse nicht zur Verfügung',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_CITY_DESC' => 'Geben Sie Ihren Ort an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_CITY_TITLE' => 'Ort',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_COUNTRY_DESC' => 'Geben Sie Ihr Land an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_COUNTRY_TITLE' => 'Land',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_EMAIL_DESC' => 'Geben Sie Ihren Email an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_EMAIL_TITLE' => 'Email',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_FIRM_DESC' => 'Geben Sie Ihren Firmennamen an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_FIRM_TITLE' => 'Rechnungsadresse: <br>Firmenname',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_NAME_DESC' => 'Geben Sie Ihren Vor- und Zunamen an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_NAME_TITLE' => 'Vor-Zuname',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_PHONE_DESC' => 'Geben Sie Ihre Telefonnummer an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_PHONE_TITLE' => 'Telefonnummer',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_POSTCODE_DESC' => 'Geben Sie Ihre PLZ an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_POSTCODE_TITLE' => 'PLZ',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_STREET_DESC' => 'Geben Sie Ihre Straße an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_STREET_TITLE' => 'Straße / Hausnummer',
	'MODULE_SHIPPING_INTERKURIER_NOTIFICATION_DESC' => 'Kundenbenachrichtigung bei Änderung des Status "Expressversand freigegeben"',
	'MODULE_SHIPPING_INTERKURIER_NOTIFICATION_TITLE' => 'Automatische Kundenbenachrichtigung',
	'MODULE_SHIPPING_INTERKURIER_SORT_ORDER_DESC' => 'Niedrigste wird zuerst angezeigt.',
	'MODULE_SHIPPING_INTERKURIER_SORT_ORDER_TITLE' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_INTERKURIER_STATUS_DESC' => 'Wollen Sie den Versand durch Interkurier anbieten?',
	'MODULE_SHIPPING_INTERKURIER_STATUS_TITLE' => 'Interkurier Express',
	'MODULE_SHIPPING_INTERKURIER_TAX_CLASS_DESC' => 'Wählen Sie den MwSt.-Satz für diese Versandart aus.',
	'MODULE_SHIPPING_INTERKURIER_TAX_CLASS_TITLE' => 'Steuersatz',
	'MODULE_SHIPPING_INTERKURIER_TEXT_DESCRIPTION' => 'Interkurier Express - Versandmodul',
	'MODULE_SHIPPING_INTERKURIER_TEXT_TITLE' => 'Interkurier Express ',
	'MODULE_SHIPPING_INTERKURIER_TEXT_UNITS' => ' ',
	'MODULE_SHIPPING_INTERKURIER_TEXT_WAY' => 'Interkurier Versandkosten (Express)',
	'MODULE_SHIPPING_INTERKURIER_UNDEFINED_RATE' => 'Die Versandkosten können nicht errechnet werden.',
	'MODULE_SHIPPING_INTERKURIER_ZONE_DESC' => 'Wenn Sie eine Zone auswählen, wird diese Versandart nur in dieser Zone angeboten.',
	'MODULE_SHIPPING_INTERKURIER_ZONE_TITLE' => 'Versand Zone'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/interkurier.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	interkurier.lang.inc.php 2025-03-28
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2025 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_INTERKURIER_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll, z. B.: AT,DE.',
	'MODULE_SHIPPING_INTERKURIER_ALLOWED_TITLE' => 'Einzelne Versandzonen',
	'MODULE_SHIPPING_INTERKURIER_COST_1_DESC' => 'Versandkosten Zone 1',
	'MODULE_SHIPPING_INTERKURIER_COST_1_TITLE' => 'Tarife Zone 1',
	'MODULE_SHIPPING_INTERKURIER_COST_2_DESC' => 'Versandkosten Zone 2',
	'MODULE_SHIPPING_INTERKURIER_COST_2_TITLE' => 'Tarife Zone 2',
	'MODULE_SHIPPING_INTERKURIER_COST_3_DESC' => 'Versandkosten Zone 3',
	'MODULE_SHIPPING_INTERKURIER_COST_3_TITLE' => 'Tarife Zone 3',
	'MODULE_SHIPPING_INTERKURIER_COST_4_DESC' => 'Versandkosten Zone 4',
	'MODULE_SHIPPING_INTERKURIER_COST_4_TITLE' => 'Tarife Zone 4',
	'MODULE_SHIPPING_INTERKURIER_COST_5_DESC' => 'Versandkosten Zone 5',
	'MODULE_SHIPPING_INTERKURIER_COST_5_TITLE' => 'Tarife Zone 5',
	'MODULE_SHIPPING_INTERKURIER_COST_6_DESC' => 'Versandkosten Zone 6',
	'MODULE_SHIPPING_INTERKURIER_COST_6_TITLE' => 'Tarife Zone 6',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_1_DESC' => 'Komma getrennte ISO-Kürzel für Zone 1:',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_1_TITLE' => 'Länder für Zone 1',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_2_DESC' => 'Komma getrennte ISO-Kürzel für Zone 2:',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_2_TITLE' => 'Länder für Zone 2',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_3_DESC' => 'Komma getrennte ISO-Kürzel für Zone 3:',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_3_TITLE' => 'Länder für Zone 3',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_4_DESC' => 'Komma getrennte ISO-Kürzel für Zone 4:',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_4_TITLE' => 'Länder für Zone 4',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_5_DESC' => 'Komma getrennte ISO-Kürzel für Zone 5:',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_5_TITLE' => 'Länder für Zone 5',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_6_DESC' => 'Komma getrennte ISO-Kürzel für Zone 6:',
	'MODULE_SHIPPING_INTERKURIER_COUNTRIES_6_TITLE' => 'Länder für Zone 6',
	'MODULE_SHIPPING_INTERKURIER_FETCH_CITY_DESC' => 'Gib deinen Ort an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_CITY_TITLE' => 'Ort',
	'MODULE_SHIPPING_INTERKURIER_FETCH_COUNTRY_DESC' => 'Gib dein Land an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_COUNTRY_TITLE' => 'Land',
	'MODULE_SHIPPING_INTERKURIER_FETCH_EMAIL_DESC' => 'Gib deine E-Mail an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_EMAIL_TITLE' => 'Email',
	'MODULE_SHIPPING_INTERKURIER_FETCH_FIRM_DESC' => 'Gib deinen Firmennamen an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_FIRM_TITLE' => 'Paketabholadresse: <br>Firmenname',
	'MODULE_SHIPPING_INTERKURIER_FETCH_NAME_DESC' => 'Gib deinen Vor- und Zunamen an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_NAME_TITLE' => 'Vor-Zuname',
	'MODULE_SHIPPING_INTERKURIER_FETCH_PHONE_DESC' => 'Gib deine Telefonnummer an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_PHONE_TITLE' => 'Telefonnummer',
	'MODULE_SHIPPING_INTERKURIER_FETCH_POSTCODE_DESC' => 'Gib deine PLZ an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_POSTCODE_TITLE' => 'Postleitzahl',
	'MODULE_SHIPPING_INTERKURIER_FETCH_STREET_DESC' => 'Gib deine Straße an',
	'MODULE_SHIPPING_INTERKURIER_FETCH_STREET_TITLE' => 'Straße / Hausnummer',
	'MODULE_SHIPPING_INTERKURIER_HANDLING_DESC' => 'Bearbeitungszuschlag für diese Versandart in Euro',
	'MODULE_SHIPPING_INTERKURIER_HANDLING_TITLE' => 'Zuschlag',
	'MODULE_SHIPPING_INTERKURIER_INVALID_ZONE' => 'Diese Option steht für ihre Lieferadresse nicht zur Verfügung',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_CITY_DESC' => 'Gib deinen Ort an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_CITY_TITLE' => 'Ort',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_COUNTRY_DESC' => 'Gib dein Land an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_COUNTRY_TITLE' => 'Land',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_EMAIL_DESC' => 'Gib deinen Email an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_EMAIL_TITLE' => 'Email',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_FIRM_DESC' => 'Gib deinen Firmennamen an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_FIRM_TITLE' => 'Rechnungsadresse: <br>Firmenname',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_NAME_DESC' => 'Gib deinen Vor- und Zunamen an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_NAME_TITLE' => 'Vor-Zuname',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_PHONE_DESC' => 'Gib deine Telefonnummer an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_PHONE_TITLE' => 'Telefonnummer',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_POSTCODE_DESC' => 'Gib deine PLZ an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_POSTCODE_TITLE' => 'Postleitzahl',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_STREET_DESC' => 'Gib deine Straße an',
	'MODULE_SHIPPING_INTERKURIER_INVOICE_STREET_TITLE' => 'Straße / Hausnummer',
	'MODULE_SHIPPING_INTERKURIER_NOTIFICATION_DESC' => 'Kundenbenachrichtigung bei Änderung des Status "Expressversand freigegeben"',
	'MODULE_SHIPPING_INTERKURIER_NOTIFICATION_TITLE' => 'Automatische Kundenbenachrichtigung',
	'MODULE_SHIPPING_INTERKURIER_SORT_ORDER_DESC' => 'Niedrigste wird zuerst angezeigt.',
	'MODULE_SHIPPING_INTERKURIER_SORT_ORDER_TITLE' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_INTERKURIER_STATUS_DESC' => 'Willst du den Versand durch Interkurier anbieten?',
	'MODULE_SHIPPING_INTERKURIER_STATUS_TITLE' => 'Interkurier Express',
	'MODULE_SHIPPING_INTERKURIER_TAX_CLASS_DESC' => 'Wähle den MwSt.-Satz für diese Versandart aus.',
	'MODULE_SHIPPING_INTERKURIER_TAX_CLASS_TITLE' => 'Steuersatz',
	'MODULE_SHIPPING_INTERKURIER_TEXT_DESCRIPTION' => 'Interkurier Express - Versandmodul',
	'MODULE_SHIPPING_INTERKURIER_TEXT_TITLE' => 'Interkurier Express ',
	'MODULE_SHIPPING_INTERKURIER_TEXT_UNITS' => ' ',
	'MODULE_SHIPPING_INTERKURIER_TEXT_WAY' => 'Interkurier Versandkosten (Express)',
	'MODULE_SHIPPING_INTERKURIER_UNDEFINED_RATE' => 'Die Versandkosten können nicht errechnet werden.',
	'MODULE_SHIPPING_INTERKURIER_ZONE_DESC' => 'Wenn du eine Zone auswählst, wird diese Versandart nur in dieser Zone angeboten.',
	'MODULE_SHIPPING_INTERKURIER_ZONE_TITLE' => 'Versand Zone'
);
